@@ -8,8 +8,7 @@ always the case.
 """
 
 from docx2python.main import docx2python
-
-from .conftest import RESOURCES
+from tests.conftest import RESOURCES
 
 
 class TestHyperlink:
