@@ -9,8 +9,7 @@ import tempfile
 
 from docx2python.main import docx2python
 from docx2python.utilities import get_headings, get_links, replace_docx_text
-
-from .conftest import RESOURCES
+from tests.conftest import RESOURCES
 
 
 class TestSearchReplace:
@@ -18,14 +17,19 @@ class TestSearchReplace:
         """Apples -> Pears, Pears -> Apples
 
         Ignore html differences when html is False"""
+
+        # assert test file is in default state
         html = False
         input_filename = RESOURCES / "apples_and_pears.docx"
+        expect = (
+            "Apples and Pears\n\nPears and Apples\n\n"
+            "Apples and Pears\n\nPears and Apples"
+        )
         with docx2python(input_filename, html=html) as input_doc:
-            assert input_doc.text == (
-                "Apples and Pears\n\nPears and Apples\n\n"
-                "Apples and Pears\n\nPears and Apples"
-            )
+            result = input_doc.text
+        assert result == expect
 
+        # attempt a search and replace
         with tempfile.TemporaryDirectory() as temp_dir:
             output_filename = os.path.join(temp_dir, "pears_and_apples.docx")
             replace_docx_text(
@@ -36,11 +40,14 @@ class TestSearchReplace:
                 ("Bananas", "Pears"),
                 html=html,
             )
+            expect = (
+                "Pears and Apples\n\nApples and Pears\n\n"
+                "Pears and Apples\n\nApples and Pears"
+            )
             with docx2python(output_filename, html=html) as output_doc:
-                assert output_doc.text == (
-                    "Pears and Apples\n\nApples and Pears\n\n"
-                    "Pears and Apples\n\nApples and Pears"
-                )
+                result = output_doc.text
+
+            assert result == expect
 
     def test_ampersand(self) -> None:
         """Apples -> Pears, Pears -> Apples
@@ -130,6 +137,6 @@ def test_get_links() -> None:
 def test_get_headings() -> None:
     """Return all headings (paragraphs with heading style) in document"""
     assert [x for x in get_headings(RESOURCES / "example.docx")] == [
-        ["Heading1", "Heading 1"],
-        ["Heading2", "Heading 2"],
+        ["<h1>", "Heading 1", "</h1>"],
+        ["<h2>", "Heading 2", "</h2>"],
     ]
